@@ -64,9 +64,12 @@ describe 'neutron::agents::ml2::ovs' do
       should contain_neutron_agent_ovs('ovs/int_peer_patch_port').with_ensure('absent')
       should contain_neutron_agent_ovs('ovs/tun_peer_patch_port').with_ensure('absent')
       should contain_neutron_agent_ovs('agent/tunnel_types').with_ensure('absent')
+      should contain_neutron_agent_ovs('ovs/bridge_mac_table_size').with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('ovs/igmp_snooping_enable').with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('ovs/resource_provider_bandwidths').\
         with_value('<SERVICE DEFAULT>')
+      should contain_neutron_agent_ovs('ovs/resource_provider_hypervisors').\
+        with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('agent/explicitly_egress_direct').with_value(['<SERVICE DEFAULT>'])
     end
 
@@ -322,13 +325,20 @@ describe 'neutron::agents::ml2::ovs' do
       it { should raise_error(Puppet::Error, /Enabling DPDK without manage vswitch does not have any effect/) }
     end
 
-    context 'when resource_provider_bandwidths is set' do
+    context 'when parameters for resource providers are set' do
       before :each do
-        params.merge!(:resource_provider_bandwidths => ['provider-a', 'provider-b'])
+        params.merge!(
+          :resource_provider_bandwidths  => ['provider-a', 'provider-b'],
+          :resource_provider_hypervisors => ['provider-a:compute-a', 'provider-b:compute-b'],
+        )
       end
 
-      it { should contain_neutron_agent_ovs('ovs/resource_provider_bandwidths').\
-        with_value('provider-a,provider-b') }
+      it 'configures resource providers' do
+        should contain_neutron_agent_ovs('ovs/resource_provider_bandwidths').\
+          with_value('provider-a,provider-b')
+        should contain_neutron_agent_ovs('ovs/resource_provider_hypervisors').\
+          with_value('provider-a:compute-a,provider-b:compute-b')
+      end
     end
 
   end
@@ -371,6 +381,16 @@ describe 'neutron::agents::ml2::ovs' do
       end
     end
 
+    context 'with mac table size on an ovs bridge set' do
+      before :each do
+        params.merge!(:bridge_mac_table_size => 50000)
+      end
+
+      it 'configure neutron/plugins/ml2/ml2_conf.ini' do
+        should contain_neutron_agent_ovs('ovs/bridge_mac_table_size').with_value(50000)
+      end
+    end
+
     context 'with IGMP snooping enabled' do
       before :each do
         params.merge!(:igmp_snooping_enable => true)
